//#define XERR
#include "agegroupvsd.ih"

void AgeGroupVSD::vary()
{
    d_vsd.vary();
}
